Index: src/crankshaft/x64/lithium-codegen-x64.cc |
diff --git a/src/crankshaft/x64/lithium-codegen-x64.cc b/src/crankshaft/x64/lithium-codegen-x64.cc |
index 335591899bbbe5605fe579b2438b3a86dc6b507c..620b5f9d27877ca35bd37f82a3816c210c3e3382 100644 |
--- a/src/crankshaft/x64/lithium-codegen-x64.cc |
+++ b/src/crankshaft/x64/lithium-codegen-x64.cc |
@@ -3121,11 +3121,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ j(not_equal, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ Cmp(FieldOperand(result, Cell::kValueOffset), |
- Smi::FromInt(Isolate::kArrayProtectorValid)); |
+ Smi::FromInt(Isolate::kArrayElementsProtectorValid)); |
DeoptimizeIf(not_equal, instr, Deoptimizer::kHole); |
} |
__ Move(result, isolate()->factory()->undefined_value()); |
@@ -3121,11 +3121,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |